@@ -38,6 +38,8 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
             pass
         for button in (self.uploadsButton, self.favouritesButton, self.playlistsButton, self.subscriptionsButton):
             button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;")
+        self.keyPressEvent = self.showSearchDialog
+        self.searchDialogRaised = False
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
@@ -45,6 +47,21 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         if len(youtubeservice.YouTubeDataService.userDict) <= 1:
             self.actionSwitchAccount.setVisible(False)
         self.show()
+        
+    def showSearchDialog(self,  event):
+        """
+        Raises a SearchDialog when the user presses a key.
+        """
+        if event.key() not in (Qt.Key_Left, Qt.Key_Right, Qt.Key_Up, Qt.Key_Down, Qt.Key_Backspace, Qt.Key_Return, Qt.Key_Control, Qt.Key_Shift, Qt.Key_Space) and not self.searchDialogRaised:
+            self.setSearchDialogRaised(True)
+            searchDialog = cutetubedialogs.SearchDialog(self)
+            searchDialog.lineEdit.insert(event.text())
+            QTimer.singleShot(1000,  lambda isRaised = False: self.setSearchDialogRaised(isRaised))
+        else:
+            pass
+            
+    def setSearchDialogRaised(self,  isRaised):
+        self.searchDialogRaised = isRaised
 
 
     def orientationChanged(self):
